==> tellico_2.3.9+dfsg.1.orig.tar.xz: tellico-2.3.9+dfsg.1/src/bibtexkeydialog.h <==
/***************************************************************************
    Copyright (C) 2011 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_BIBTEXKEYDIALOG_H
#define TELLICO_BIBTEXKEYDIALOG_H

#include <kdialog.h>

#include "datavectors.h"
#include "filter.h"

class KTitleWidget;

namespace Tellico {

/**
 * @author Robby Stephenson
 */
class BibtexKeyDialog : public KDialog {
Q_OBJECT

public:
  BibtexKeyDialog(Data::CollPtr coll, QWidget* parent);
  virtual ~BibtexKeyDialog();

signals:
  void signalUpdateFilter(Tellico::FilterPtr);

public slots:
  void slotCheckDuplicates();

private slots:
  void slotCheckDuplicatesImpl();
  void slotFilterDuplicates();

private:
  Data::CollPtr m_coll;
  Data::EntryList m_dupes;
  
  KTitleWidget* m_dupeLabel;
};

} // end namespace
#endif

==> tellico_4.1.4.orig.tar.xz: tellico-4.1.4/src/bibtexkeydialog.h <==
/***************************************************************************
    Copyright (C) 2011 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_BIBTEXKEYDIALOG_H
#define TELLICO_BIBTEXKEYDIALOG_H

#include <QDialog>

#include "datavectors.h"
#include "filter.h"

class KTitleWidget;

class QPushButton;

namespace Tellico {

/**
 * @author Robby Stephenson
 */
class BibtexKeyDialog : public QDialog {
Q_OBJECT

public:
  BibtexKeyDialog(Data::CollPtr coll, QWidget* parent);
  virtual ~BibtexKeyDialog();

Q_SIGNALS:
  void signalUpdateFilter(Tellico::FilterPtr);

public Q_SLOTS:
  void slotCheckDuplicates();

private Q_SLOTS:
  void slotCheckDuplicatesImpl();
  void slotFilterDuplicates();

private:
  Data::CollPtr m_coll;
  Data::EntryList m_dupes;

  KTitleWidget* m_dupeLabel;
  QPushButton* m_filterButton;
};

} // end namespace
#endif
